==> rustitude-0.4.0.tar.gz: rustitude-0.4.0/crates/rustitude-gluex/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.2.0 (2024-05-15)

### Documentation

 - <csr-id-93dc0d6cfeb57f655c81f30c1e55b1c6b0460ccc/> update links for rustitude-gluex readme
 - <csr-id-95f85ed6b16400c882e7535c7fa113ead9876353/> update links in readmes

### Other

 - <csr-id-9617a27322460b378fb022ef28561f31197fc86f/> merge rustitude-core to crates subdirectory

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 3 commits contributed to the release.
 - 3 commits were understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' were seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Update links for rustitude-gluex readme ([`93dc0d6`](https://github.com/denehoffman/rustitude/commit/93dc0d6cfeb57f655c81f30c1e55b1c6b0460ccc))
    - Update links in readmes ([`95f85ed`](https://github.com/denehoffman/rustitude/commit/95f85ed6b16400c882e7535c7fa113ead9876353))
    - Merge rustitude-core to crates subdirectory ([`9617a27`](https://github.com/denehoffman/rustitude/commit/9617a27322460b378fb022ef28561f31197fc86f))
</details>

## v0.1.5 (2024-05-06)

<csr-id-78c524baa32d27ed65657d28ce1ef0eacde3ed0b/>

### Documentation

 - <csr-id-c8c587aa724423bd901b2b194b40446105dca3d0/> Update README.md

### Bug Fixes

 - <csr-id-9d41bce7308c9839e1169c07365229c17be557d8/> minor updates to text format
 - <csr-id-cc42f164db96559dda08a3b15d5074475625295c/> let the rustitude crate handle module inits
 - <csr-id-e5a4a49fb9b945661d8c4ab9aeb72b597f2647a4/> update to include submodule initialization

### Other

 - <csr-id-78c524baa32d27ed65657d28ce1ef0eacde3ed0b/> update Cargo.lock

## v0.1.4 (2024-05-03)

<csr-id-fb1e8f512409dd34cc197a6e76a5376d3781eac9/>

### Other

 - <csr-id-fb1e8f512409dd34cc197a6e76a5376d3781eac9/> remove unused library that was causing compilation errors further on up

## v0.1.3 (2024-05-02)

<csr-id-c91284ad855463940c849c8c11f7c43d67c35288/>
<csr-id-de2a33d7f496862d82ebf488b43e5750548afd94/>

### Chore

 - <csr-id-c91284ad855463940c849c8c11f7c43d67c35288/> update rustitude-core version

### New Features

 - <csr-id-3e3619b4736c93ecd5094c4bbd150221afb17bd6/> add pyo3 bindings for all current modules and amplitudes
 - <csr-id-a94baf2dc37165d5911bb72c336fdae0355dff92/> add parsers for current util enums

### Other

 - <csr-id-de2a33d7f496862d82ebf488b43e5750548afd94/> update Cargo.toml

## v0.1.2 (2024-04-29)

<csr-id-066062486c30e0df1760aa67e7df2ff14e082e52/>
<csr-id-685288f07f38eb5b3b7d773bf989bb6a2bc034ee/>

### Chore

 - <csr-id-066062486c30e0df1760aa67e7df2ff14e082e52/> Create LICENSE

### Documentation

 - <csr-id-33b8eaf2481fb0e013fb683f3f75d64a813f6d60/> fix README.md link to documentation
 - <csr-id-45e4cf8e192492f400fa1394ca3be5fd2e8ab1ea/> fix badge links in README.md

### New Features

 - <csr-id-ab6c8883b3676c837d168cb91053d6ea9b2b1330/> implement ThreePiAnglesSchilling.cc as sdmes::ThreePiSDME
 - <csr-id-b857ee844d4c12b242d4d8239c02c9c88ea8c1b8/> implement TwoPiAngles.cc as sdmes::TwoPiSDME
 - <csr-id-83d46cfdb1fb4b4ef65f5fa3b5c2be3b30ad4532/> refactor harmonics::{ReZlm, ImZlm} and add OnePS and TwoPS
   Added Frame and Part enums to be used with all of these amplitudes to simplify requests for just the real or imaginary parts of amplitudes. Additionally, we can now specify the Frame (Helicity/GJ). Therefore, we only need a Zlm struct rather than the split structs before.
 - <csr-id-f6b4e0d0408e6be431c3947098512b51ad5a253a/> add helper methods for Wigner D-matrices

### Bug Fixes

 - <csr-id-7175f39998c4156988799cf5e599bf840aca6d8d/> switch from rustitude to rustitude_core dependency
 - <csr-id-77dec26ac644811614ff735c229c2016882c392f/> modify the way Frames work with daughter vector inputs
   This is in preparation for the ThreePiAnglesSchilling.cc implementation.
 - <csr-id-5caca39cac184296ed6eb1a3de2258fc6cf51d36/> move useful enums into utils
 - <csr-id-87b83e8bb22fb1135862cf4138f26388a2ee17bc/> make OmegaDalitz public

### Other

 - <csr-id-685288f07f38eb5b3b7d773bf989bb6a2bc034ee/> remove local dependency

## v0.1.1 (2024-04-10)

<csr-id-9899faf055e30e68db3a88e09a5064c4767f8882/>
<csr-id-c53ab0d05b5adf9a241f74626361dba127f631bc/>
<csr-id-068054ec1ced218698e2606ac513c08219f1c958/>
<csr-id-d66f984bb5a6c1fd7144655d7f2e8dffc3bb6554/>

### Chore

 - <csr-id-9899faf055e30e68db3a88e09a5064c4767f8882/> update rustitude version

### Documentation

 - <csr-id-2d97b61e6f66d215585789793e94707b85454e73/> Update README.md

### New Features

 - <csr-id-bc6efb37bd59699cde73c18427c998080dc85791/> reorganize modules and add some new Amplitudes
   Add Rho K-Matrix, Omega-Dalitz, and Breit-Wigner, move some K-Matrix functions to utils, add placeholder module for SDMEs

### Bug Fixes

 - <csr-id-042cfeb1d371903a3a366ea4859ba069ad3c7f0f/> reorganization and local versioning on rustitude

### Other

 - <csr-id-c53ab0d05b5adf9a241f74626361dba127f631bc/> Create rust.yml

### Style

 - <csr-id-068054ec1ced218698e2606ac513c08219f1c958/> update logo
 - <csr-id-d66f984bb5a6c1fd7144655d7f2e8dffc3bb6554/> remove now-redundant imports of Complex64

==> rustitude-0.4.2.tar.gz: rustitude-0.4.2/crates/rustitude-gluex/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.2.1 (2024-05-15)

### Refactor

 - <csr-id-9089c84e481124ff764b24f42507ab14913fef07/> major move required to have rustitude function properly as a Rust crate. I set this up very wrong the first time

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 1 commit contributed to the release.
 - 1 commit was understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' were seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Major move required to have rustitude function properly as a Rust crate. I set this up very wrong the first time ([`9089c84`](https://github.com/denehoffman/rustitude/commit/9089c84e481124ff764b24f42507ab14913fef07))
</details>

## v0.2.0 (2024-05-15)

<csr-id-9617a27322460b378fb022ef28561f31197fc86f/>

### Documentation

 - <csr-id-93dc0d6cfeb57f655c81f30c1e55b1c6b0460ccc/> update links for rustitude-gluex readme
 - <csr-id-95f85ed6b16400c882e7535c7fa113ead9876353/> update links in readmes

### Other

 - <csr-id-9617a27322460b378fb022ef28561f31197fc86f/> merge rustitude-core to crates subdirectory

### Bug Fixes

 - <csr-id-2495107c77f483b84a926090cd868ccec8296052/> need to set some dependency versions...
 - <csr-id-ee48e4039e40bbf2c5b23d230bbcd0213c41e888/> need to set some dependency versions...properly

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 8 commits contributed to the release.
 - 5 commits were understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' were seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release rustitude-gluex v0.2.0, rustitude v0.4.0 ([`bc38f3a`](https://github.com/denehoffman/rustitude/commit/bc38f3af06807d8e6e1c3ca3a38581461ef934b8))
    - Need to set some dependency versions...properly ([`ee48e40`](https://github.com/denehoffman/rustitude/commit/ee48e4039e40bbf2c5b23d230bbcd0213c41e888))
    - Release rustitude-gluex v0.2.0, rustitude v0.4.0 ([`1369408`](https://github.com/denehoffman/rustitude/commit/1369408a7352be0e5b5fb675b0127e8e69a10c59))
    - Need to set some dependency versions... ([`2495107`](https://github.com/denehoffman/rustitude/commit/2495107c77f483b84a926090cd868ccec8296052))
    - Release rustitude-core v1.0.0, rustitude-gluex v0.2.0, rustitude v0.4.0, safety bump 2 crates ([`23a8807`](https://github.com/denehoffman/rustitude/commit/23a880783702368ee873ce4839310f4b392c6862))
    - Update links for rustitude-gluex readme ([`93dc0d6`](https://github.com/denehoffman/rustitude/commit/93dc0d6cfeb57f655c81f30c1e55b1c6b0460ccc))
    - Update links in readmes ([`95f85ed`](https://github.com/denehoffman/rustitude/commit/95f85ed6b16400c882e7535c7fa113ead9876353))
    - Merge rustitude-core to crates subdirectory ([`9617a27`](https://github.com/denehoffman/rustitude/commit/9617a27322460b378fb022ef28561f31197fc86f))
</details>

## v0.1.5 (2024-05-06)

<csr-id-78c524baa32d27ed65657d28ce1ef0eacde3ed0b/>

### Documentation

 - <csr-id-c8c587aa724423bd901b2b194b40446105dca3d0/> Update README.md

### Bug Fixes

 - <csr-id-9d41bce7308c9839e1169c07365229c17be557d8/> minor updates to text format
 - <csr-id-cc42f164db96559dda08a3b15d5074475625295c/> let the rustitude crate handle module inits
 - <csr-id-e5a4a49fb9b945661d8c4ab9aeb72b597f2647a4/> update to include submodule initialization

### Other

 - <csr-id-78c524baa32d27ed65657d28ce1ef0eacde3ed0b/> update Cargo.lock

## v0.1.4 (2024-05-03)

<csr-id-fb1e8f512409dd34cc197a6e76a5376d3781eac9/>

### Other

 - <csr-id-fb1e8f512409dd34cc197a6e76a5376d3781eac9/> remove unused library that was causing compilation errors further on up

## v0.1.3 (2024-05-02)

<csr-id-c91284ad855463940c849c8c11f7c43d67c35288/>
<csr-id-de2a33d7f496862d82ebf488b43e5750548afd94/>

### Chore

 - <csr-id-c91284ad855463940c849c8c11f7c43d67c35288/> update rustitude-core version

### New Features

 - <csr-id-3e3619b4736c93ecd5094c4bbd150221afb17bd6/> add pyo3 bindings for all current modules and amplitudes
 - <csr-id-a94baf2dc37165d5911bb72c336fdae0355dff92/> add parsers for current util enums

### Other

 - <csr-id-de2a33d7f496862d82ebf488b43e5750548afd94/> update Cargo.toml

## v0.1.2 (2024-04-29)

<csr-id-066062486c30e0df1760aa67e7df2ff14e082e52/>
<csr-id-685288f07f38eb5b3b7d773bf989bb6a2bc034ee/>

### Chore

 - <csr-id-066062486c30e0df1760aa67e7df2ff14e082e52/> Create LICENSE

### Documentation

 - <csr-id-33b8eaf2481fb0e013fb683f3f75d64a813f6d60/> fix README.md link to documentation
 - <csr-id-45e4cf8e192492f400fa1394ca3be5fd2e8ab1ea/> fix badge links in README.md

### New Features

 - <csr-id-ab6c8883b3676c837d168cb91053d6ea9b2b1330/> implement ThreePiAnglesSchilling.cc as sdmes::ThreePiSDME
 - <csr-id-b857ee844d4c12b242d4d8239c02c9c88ea8c1b8/> implement TwoPiAngles.cc as sdmes::TwoPiSDME
 - <csr-id-83d46cfdb1fb4b4ef65f5fa3b5c2be3b30ad4532/> refactor harmonics::{ReZlm, ImZlm} and add OnePS and TwoPS
   Added Frame and Part enums to be used with all of these amplitudes to simplify requests for just the real or imaginary parts of amplitudes. Additionally, we can now specify the Frame (Helicity/GJ). Therefore, we only need a Zlm struct rather than the split structs before.
 - <csr-id-f6b4e0d0408e6be431c3947098512b51ad5a253a/> add helper methods for Wigner D-matrices

### Bug Fixes

 - <csr-id-7175f39998c4156988799cf5e599bf840aca6d8d/> switch from rustitude to rustitude_core dependency
 - <csr-id-77dec26ac644811614ff735c229c2016882c392f/> modify the way Frames work with daughter vector inputs
   This is in preparation for the ThreePiAnglesSchilling.cc implementation.
 - <csr-id-5caca39cac184296ed6eb1a3de2258fc6cf51d36/> move useful enums into utils
 - <csr-id-87b83e8bb22fb1135862cf4138f26388a2ee17bc/> make OmegaDalitz public

### Other

 - <csr-id-685288f07f38eb5b3b7d773bf989bb6a2bc034ee/> remove local dependency

## v0.1.1 (2024-04-10)

<csr-id-9899faf055e30e68db3a88e09a5064c4767f8882/>
<csr-id-c53ab0d05b5adf9a241f74626361dba127f631bc/>
<csr-id-068054ec1ced218698e2606ac513c08219f1c958/>
<csr-id-d66f984bb5a6c1fd7144655d7f2e8dffc3bb6554/>

### Chore

 - <csr-id-9899faf055e30e68db3a88e09a5064c4767f8882/> update rustitude version

### Documentation

 - <csr-id-2d97b61e6f66d215585789793e94707b85454e73/> Update README.md

### New Features

 - <csr-id-bc6efb37bd59699cde73c18427c998080dc85791/> reorganize modules and add some new Amplitudes
   Add Rho K-Matrix, Omega-Dalitz, and Breit-Wigner, move some K-Matrix functions to utils, add placeholder module for SDMEs

### Bug Fixes

 - <csr-id-042cfeb1d371903a3a366ea4859ba069ad3c7f0f/> reorganization and local versioning on rustitude

### Other

 - <csr-id-c53ab0d05b5adf9a241f74626361dba127f631bc/> Create rust.yml

### Style

 - <csr-id-068054ec1ced218698e2606ac513c08219f1c958/> update logo
 - <csr-id-d66f984bb5a6c1fd7144655d7f2e8dffc3bb6554/> remove now-redundant imports of Complex64
